@@ -3,34 +3,29 @@
 
 import sys
 import traceback
-
 import dbus
 import dbus.mainloop.qt
 import alarm
-#import timer
 import os
 import cPickle
-
-from time import time
-
+from time import time, strftime
 from PyQt4 import QtGui, QtCore
 
 from rest_in_peace_gui import *
 
-#mytimer = timer.Timer()
-
 class MyForm(QtGui.QMainWindow):
-    enableLogging = False;
-    enableAlarm = False;
-    enableGSMAlarm = False;
-    searchCellID = 0;  #modified when you choose a favorite. This variable holds the match the system searches for
-
-    cellID_list_changed=False
-
-    cellID_list = {}
-    cellID_name = ""
-
     def __init__(self, parent=None):
+        self.enableLogging = False;
+        self.enableAlarm = True;
+        self.enableGSMAlarm = False;
+        self.searchCellID = 0;  #modified when you choose a favorite. This variable holds the match the system searches for
+
+        self.cellID_list_changed=False
+
+        self.cellID_list = {}
+        self.cellID_name = ""
+        self.current_cellid = 0
+
         #build parent user interface
         QtGui.QWidget.__init__(self, parent)
         self.ui = Ui_MainWindow()
@@ -47,7 +42,7 @@ class MyForm(QtGui.QMainWindow):
         #connect the buttons
         QtCore.QObject.connect(self.ui.pushButtonStart, QtCore.SIGNAL('clicked()'), self.doStart)
         QtCore.QObject.connect(self.ui.pushButtonFav, QtCore.SIGNAL('clicked()'), self.doSaveCurrent)
-        QtCore.QObject.connect(self.ui.checkBoxAlarm, QtCore.SIGNAL('stateChanged(int)'), self.setAlarm)
+#        QtCore.QObject.connect(self.ui.checkBoxAlarm, QtCore.SIGNAL('stateChanged(int)'), self.setAlarm)
         QtCore.QObject.connect(self.ui.checkBoxGSMAlarm, QtCore.SIGNAL('stateChanged(int)'), self.setGSMAlarm)
         QtCore.QObject.connect(self.ui.checkBoxLogging, QtCore.SIGNAL('stateChanged(int)'), self.setLogging)
         QtCore.QObject.connect(self.ui.comboBoxFav, QtCore.SIGNAL('currentIndexChanged(QString)'), self.changeCellID)
@@ -57,6 +52,9 @@ class MyForm(QtGui.QMainWindow):
         QtCore.QObject.connect(self.ui.actionMenuTips, QtCore.SIGNAL('triggered()'), self.showTips)
         QtCore.QObject.connect(self.ui.actionMenuEdit, QtCore.SIGNAL('triggered()'), self.edit_dialog)
 
+#        self.ui.checkBoxAlarm.setTristate(self.enableAlarm)
+        self.ui.checkBoxGSMAlarm.setTristate(self.enableGSMAlarm)
+
         dbus.mainloop.qt.DBusQtMainLoop(set_as_default=True)
         bus = dbus.SystemBus()
         # get Current registered Cell ID
@@ -67,12 +65,12 @@ class MyForm(QtGui.QMainWindow):
         if int(cellinfo.get_selected_radio_access_technology()[0]) != 1:
             QtGui.QMessageBox.information(self, "3G networks are allowed in settings", "Please use 2G-only (GSM) networks to ensure stable behaviour. Go to Settings > Phone > Network mode to change it.")
         #update UI with current CellID
-        self.ui.spinBoxCellID.setValue(cellinfo.get_registration_status()[2])
+        self.current_cellid = cellinfo.get_registration_status()[2]
+        self.update_name()
 
         bus.add_signal_receiver(cell_signal_handler, dbus_interface = "Phone.Net", signal_name = "registration_status_change")
         bus.add_signal_receiver(cell_signal_handler, dbus_interface = "Phone.Net", signal_name = "cell_info_change")
 
-
     def setup_settings(self):
         QtCore.QCoreApplication.setOrganizationName('Rest In Peace')
         QtCore.QCoreApplication.setOrganizationDomain('Rest In Peace')
@@ -101,44 +99,37 @@ class MyForm(QtGui.QMainWindow):
 
 
     def doStart(self):
-        self.ui.pushButtonStart.setText("Waiting for " + str(self.ui.comboBoxFav.currentText()) + ": CellIDs " + str(self.searchCellID) + ".\n Click again to change.")
+        self.ui.pushButtonStart.setText("Waiting for a CellID from [" + str(self.ui.comboBoxFav.currentText()) + "] group.\nClick again to set new destination.")
 
     # Change the CellID to search for when User hits "go"
     def changeCellID(self, favorite):
         self.searchCellID = self.cellID_list[str(favorite)]
-        print "Pre-stored CellID: " + str( self.searchCellID )
 
     # Enable button when user modifies the text in the comboBox
     # just to give some feedback that the two controls are linked
     def enableSaveButton(self, text):
         self.ui.pushButtonFav.setEnabled( True )
 
-    # Could probably do with defaulting this to "on"
-    def setAlarm(self, value):
-        self.enableAlarm = not self.enableAlarm
-        self.ui.checkBoxAlarm.setTristate(self.enableAlarm)
-        print "alarm state set to: " + str(self.enableAlarm)
+ #   def setAlarm(self, value):
+ #       self.enableAlarm = not(self.enableAlarm)
+ #       self.ui.checkBoxAlarm.setTristate(self.enableAlarm)
 
     def setGSMAlarm(self, value):
-        print "GSM alarm checkbox changed ", str(value)
-        self.enableGSMAlarm = self.ui.checkBoxGSMAlarm.isChecked()
-        print "GSM alarm state set to: " + str(self.enableGSMAlarm)
+        self.enableGSMAlarm = not(self.enableGSMAlarm)
+        self.ui.checkBoxGSMAlarm.setChecked(self.enableGSMAlarm)
 
     # enable Logging of cellID
     def setLogging(self, value):
         self.enableLogging = not self.enableLogging
         self.ui.checkBoxLogging.setTristate(self.enableLogging)
-        self.fileObj = open("/home/user/cellID_log.txt","a")
-        print "logging state set to: " + str(self.enableLogging)
+        self.fileObj = open("/home/user/MyDocs/restinpeace_cellid_log.txt","a")
 
     # Save currentCellID and add it to the dictionary
-    def doSaveCurrent(self): # TODO: change for lists handling
+    def doSaveCurrent(self):
         print "Trying to add " + self.ui.comboBoxFav.currentText() + " : " + str(self.ui.spinBoxCellID.value()) + " to list"
-        # self.cellID_list[str(self.ui.comboBoxFav.currentText())] = self.ui.spinBoxCellID.value()
         cellName = str(self.ui.comboBoxFav.currentText())
         cellNumber = self.ui.spinBoxCellID.value()
         try:
-            #TODO: rewrite if?
             if ((cellName in self.cellID_list) and
                (cellNumber in self.cellID_list[cellName])):
                 print(str(cellNumber) + " found in " + cellName)
@@ -156,6 +147,15 @@ class MyForm(QtGui.QMainWindow):
         self.cellID_list_changed=True
         print "OK"
 
+    def update_name(self):
+        self.ui.spinBoxCellID.setSuffix("")
+        self.ui.spinBoxCellID.setValue(self.current_cellid)
+        for key in self.cellID_list.iterkeys():
+            if self.cellID_list[key].__contains__(self.current_cellid):
+                self.cellID_name = key
+                break
+        self.ui.spinBoxCellID.setSuffix(": "+self.cellID_name)
+
 
     def closeEvent(self, event):
         #Save settings
@@ -222,7 +222,6 @@ class MyForm(QtGui.QMainWindow):
         tipsString = """
 Choose one of the favorites, enable the alarm and hit 'Go'. As long as the app is running, it will sound an alarm when the phone registers itself with the GSM basestation at the destination.<br>To save the currently registered CellID, just give it a name in the dropdown and hit 'Add CellID'
 """
-        #TODO: update tips, change the return method
 	QtGui.QMessageBox.information(self, "Tips", tipsString)
 
     def showAbout(self):
@@ -232,53 +231,40 @@ Choose one of the favorites, enable the alarm and hit 'Go'. As long as the app i
     def closeTips(self):
 	self.scrollArea.close()
 
-def add_two_button_alarm( message = "We are HERE!"):
+def add_two_button_alarm( message = "R.I.P. alarm"):
     event = alarm.Event()
     event.appid = 'restinpeace'
-    event.message = message
+    event.message = "[ "+str(app_object.cellID_name)+" ] "+message
 
     event.alarm_time = time() + 1
 
     action_stop, action_snooze = event.add_actions(2)
     action_stop.label = 'Stop'
     action_stop.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_NOP
-
     action_snooze.label = 'Snooze'
     action_snooze.flags |= alarm.ACTION_WHEN_RESPONDED | alarm.ACTION_TYPE_SNOOZE
 
     cookie = alarm.add_event(event)
-
     return cookie
 
 def cell_signal_handler(*args):
     if( app_object.enableLogging ):
-        app_object.fileObj.write( time() + '--> ' + str(args[4]) + ', ' + str(args[3]) + ', ' + str(args[2]) + '\n' )
+        app_object.fileObj.write( strftime("%Y-%m-%d %H:%M:%S") + ', ' + str(args[4]) + ', ' + str(args[3]) + ', ' + str(args[2]) + '\n' )
 
+    app_object.current_cellid = args[2]
     # Update UI with current CellID
-    app_object.ui.spinBoxCellID.setSuffix("")
-    app_object.ui.spinBoxCellID.setValue(args[2])
-    for key in app_object.cellID_list.iterkeys():
-        if app_object.cellID_list[key].__contains__(args[2]):
-            app_object.cellID_name = key
-            break
-    app_object.ui.spinBoxCellID.setSuffix(": "+app_object.cellID_name)
+    app_object.update_name()
 
     # Does it match the preset CellID?
     if( app_object.searchCellID ):
-        if( args[2] in app_object.searchCellID ):
+        if( app_object.current_cellid in app_object.searchCellID ):
             if( app_object.enableAlarm ):
-                app_object.enableAlarm = False
-                app_object.ui.checkBoxAlarm.setTristate(False)
                 add_two_button_alarm()
-                #sys.exit(app_object.exec_())
-                #app_object.ui.centralwidget.setEnabled(True)
-
-            # Even if there is no alarm, give some feedback to UI that we're arrived!
-            app_object.ui.pushButtonStart.setText("We are HERE!")
+            app_object.ui.pushButtonStart.setText("Arrived at ["+app_object.cellID_name+"]. Click again to set new destination.")
 
     if( app_object.enableGSMAlarm and (args[3] != 0 and args[4] != 0) ):
         app_object.enableGSMAlarm = False
-        app_object.ui.checkBoxGSMAlarm.setChecked(False)
+        app_object.ui.checkBoxGSMAlarm.setChecked(app_object.enableGSMAlarm)
         add_two_button_alarm("GSM network available. You may not see it in the status panel if that's not your operator's station.")
 
 if __name__ == '__main__':
